@@ -4,6 +4,7 @@ import datacollector_Boliga
 import datacollector_Business_insider
 import datacollector_Entsoe
 import datacollector_energidataservice
+import datacollector_trading_economics
 
 
 class ECB(datacollector_ECB.ECB):
@@ -24,3 +25,5 @@ class Business_insider(datacollector_Business_insider.Business_insider):
 class Energidataservice(datacollector_energidataservice.Energidataservice):
     pass
 
+class Trading_economics(datacollector_trading_economics.Trading_economics):
+    pass
